pydevDAG._utils module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »

# pydevDAG._utils module

## pydevDAG._utils

Generic utilities.

class `pydevDAG._utils.` `GraphUtils`

  Bases: `object`

  Generic utilties for graphs.

  static `get_roots`(graph)

    Get the roots of a graph.

    Parameters: | graph (DiGraph) – the graph
    Returns: | the roots of the graph
    Return type: | list of Node

class `pydevDAG._utils.` `SortingUtils`

  Bases: `object`

  Utilities helpful for sorting.

  static `str_key_func_gen`(func)

    A wrapper function that generates a function that yields a str for all values.

    Parameters: | func (‘a -> *) – a function that yields a result when applied to an arg

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »